@@ -448,7 +448,7 @@ class Discriminator(nn.Module):
             )
         elif disc_output_size == 1:
             self.to_logits = nn.Sequential(
-                SN(nn.Conv2d(last_chan, last_chan, 4)),
+                SN(nn.Conv2d(last_chan, last_chan, 3, stride = 2, padding = 1)),
                 nn.LeakyReLU(0.1),
                 nn.Conv2d(last_chan, 1, 4)
             )
